<a id="autonomy.deploy.constants"></a>

# autonomy.deploy.constants

Constants for generating deployments environment.

<a id="autonomy.deploy.constants.get_ip"></a>

#### get`_`ip

```python
def get_ip() -> str
```

Get local IP address.

